==> ejc-scientific-api-3.0.0-20250828.124739-88-sources.jar: com/ejianc/business/scientific/sci/work/vo/UserMonthWorkTimeStaticVO.java <==
package com.ejianc.business.scientific.sci.work.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 员工月度工时统计主表
 * 
 * @author generator
 * 
 */
public class UserMonthWorkTimeStaticVO extends BaseVO {

    private static final long serialVersionUID = -6501935873135627934L;
    private Long employeeId; // 经办人主键
    private String employeeName; // 经办人
    private String billCode; // 单据编码
    private String memo; // 备注
    private String yearMonth; // 月份
    
    private List<UserMonthWorkTimeStaticDetailVO> detailList = new ArrayList<>(); // 员工月度工时统计子表

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getYearMonth() {
        return yearMonth;
    }

    public void setYearMonth(String yearMonth) {
        this.yearMonth = yearMonth;
    }

    public List<UserMonthWorkTimeStaticDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<UserMonthWorkTimeStaticDetailVO> detailList) {
        this.detailList = detailList;
    }
}

==> ejc-scientific-api-3.0.0-20250901.130824-93-sources.jar: com/ejianc/business/scientific/sci/work/vo/UserMonthWorkTimeStaticVO.java <==
package com.ejianc.business.scientific.sci.work.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.ArrayList;
import java.util.List;

/**
 * 员工月度工时统计主表
 * 
 * @author generator
 * 
 */
public class UserMonthWorkTimeStaticVO extends BaseVO {

    private static final long serialVersionUID = -6501935873135627934L;
    private Long employeeId; // 经办人主键
    private String employeeName; // 经办人
    private String billCode; // 单据编码
    private String memo; // 备注
    private String yearMonth; // 月份

    private Long billOrgId; //单据编制组织Id
    
    private List<UserMonthWorkTimeStaticDetailVO> detailList = new ArrayList<>(); // 员工月度工时统计子表

    public Long getBillOrgId() {
        return billOrgId;
    }

    public void setBillOrgId(Long billOrgId) {
        this.billOrgId = billOrgId;
    }

    public Long getEmployeeId() {
        return employeeId;
    }

    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

    public String getYearMonth() {
        return yearMonth;
    }

    public void setYearMonth(String yearMonth) {
        this.yearMonth = yearMonth;
    }

    public List<UserMonthWorkTimeStaticDetailVO> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<UserMonthWorkTimeStaticDetailVO> detailList) {
        this.detailList = detailList;
    }
}
